import json
from django.shortcuts import render, redirect, reverse, HttpResponseRedirect, HttpResponse
from django.views.generic import ListView, DetailView, CreateView

from .models import News, WpEsiNews, WpEsiNewsEntity, WpEsiMedia, WpEsiEntity


class ListNewsView(ListView):
    template_name = 'list_news.html'

    def get(self, request, *args, **kwargs):
        media = request.GET.get('media')
        date = request.GET.get('date')
        news = News.objects.filter(is_accepted=False).order_by('-id')#.order_by('record_date')
        if date:
            news = news.filter(record_date=date)
        if media:
            news = self._filter_by_media(news, media)
        media = WpEsiMedia.objects.all()
        return render(request, self.template_name, {'news': news,
                                                    'media': media})

    def post(self, request, *args, **kwargs):
        if request.is_ajax():
            data = json.loads(request.body.decode('utf-8'))
            type_request = data['type']
            ids = data['id']
            if type_request in ['delete', 'deleteAll']:
                self._delete(ids)
            if type_request == 'edit':
                return HttpResponseRedirect(reverse('single_news', kwargs={'id': ids}))
        return HttpResponseRedirect(reverse('list_news'))

    def _delete(self, id):
        if isinstance(id, list):
            News.objects.filter(id__in=id).update(is_accepted=True)
        else:
            News.objects.filter(id=id).update(is_accepted=True)

    def _filter_by_media(self, news, media):
        if media == 'All':
            return news
        else:
            m = WpEsiMedia.objects.get(name=media)
            news = news.filter(media_id=m.pk)
            return news



class DetailNewsView(DetailView):
    template_name = 'single_news.html'

    def get(self, request, *args, **kwargs):
        news = News.objects.get(id=kwargs.get('id'))
        media = WpEsiMedia.objects.all()
        company = WpEsiEntity.objects.get(id=news.company_id)
        return render(request, self.template_name, {'news': news,
                                                    'media': media,
                                                    'company': company})


class AcceptNewsView(CreateView):
    template_name = 'list_news.html'

    def post(self, request, *args, **kwargs):
        print(request.POST.get('item'))
        return HttpResponseRedirect(redirect_to=reverse('list_news'))
